use Test::More tests => 14;

use Env::Path;
use App::Env;


# first ensure that fparkey isn't in the path so we don't get confused

if ( Env::Path->PATH->Whence('fparkey') )
{
    diag( "The HEADAS environment is already loaded! Unload before running this test\n" );
    die();
}

# just use FTOOLS to test things

# can't really tell from the outside if HEADAS or $ENV{APP_ENV_HEADAS}
# does anything different from the default, as there's only the one
# distribution to test.


# test actual installation and aliases
test_tools( HEADAS => default => {} );
test_tools( heasoft => default => {} );
test_tools( ftools => default => {} );


# now test if alternate means of specifying things work
test_alt( 'ROOT+PLATFORM',
          'platform',
          { root => 'data', platform => 'platform' } 
        );

{ local %ENV; 
  $ENV{APP_ENV_HEADAS_ROOT} = 'data';
  test_alt( 'APP_ENV_HEADAS_ROOT+PLATFORM',
            'platform',
          { platform => 'platform' } 
          );
}
  
{ local %ENV; 
  $ENV{APP_ENV_HEADAS_PLATFORM} = 'platform';
  test_alt( 'ROOT+APP_ENV_HEADAS_PLATFORM',
            'platform', 
          { root => 'data' } 
          );
}

# and now test if the version is getting through
test_alt( 'version',
          'platform-55',
        { root => 'data', platform => 'platform', version => '55' } 
        );

{ local %ENV; 
  $ENV{APP_ENV_HEADAS_VERSION} = '55';
  test_alt( 'APP_ENV_HEADAS_VERSION',
            'platform-55',
            { root => 'data', platform => 'platform' }
          );
}
  



sub test_tools
{
    my ( $app, $prefix, $AppOpts ) = @_;

    my $env = 
      eval { 
          App::Env->new( $app, 
                       { Cache => 0, 
                         AppOpts => $AppOpts,
                       } );
      };
    my $err = $@;

  SKIP: {
        skip "module load: $err", 3 if $err;

        my $time = time();
        ok( 0 == $env->system( 'fparkey', 'fitsfile=data/test.fits[0]', 'keyword=date', "value=$time" ),
            "$prefix: run fparkey" );

        ok( 0 == $env->system( 'ftkeypar', 'infile=data/test.fits[0]', 'keyword=date' ), "$prefix: run ftkeypar" );

        
        my $rtime = eval { $env->qexec( 'pget', 'ftkeypar', 'value') };

        skip "pget error: $@", 1 if $@;

        chomp $rtime;

        is( $rtime, $time, "$prefix: check keyword" );
    }

}

sub test_alt
{
    my ( $prefix, $expected, $AppOpts ) = @_;

    my $env = 
      eval { 
          App::Env->new( 'HEADAS', 
                       { Cache => 0, 
                         AppOpts => $AppOpts,
                       } );
      };
    my $err = $@;

  SKIP: {
        skip "module load: $err", 1 if $err;

        is( $env->env( 'HEADAS' ), $expected, "$prefix: check environment" );
    }

}
